@@ -1,6 +1,7 @@
 import time
 import hashlib
 import re
+import urllib
 
 from .common import InfoExtractor
 from ..utils import (
@@ -13,7 +14,7 @@ from ..utils import (
 
 class DouyuTVIE(InfoExtractor):
     IE_DESC = '斗鱼'
-    _VALID_URL = r'https?://(?:www\.)?douyu(?:tv)?\.com/(?:[^/]+/)*(?P<id>[A-Za-z0-9]+)'
+    _VALID_URL = r'https?://(?:www\.)?douyu(?:tv)?\.com/(topic/\w+\?rid=|(?:[^/]+/))*(?P<id>[A-Za-z0-9]+)'
     _TESTS = [{
         'url': 'http://www.douyutv.com/iseven',
         'info_dict': {
@@ -22,7 +23,7 @@ class DouyuTVIE(InfoExtractor):
             'ext': 'flv',
             'title': 're:^清晨醒脑！根本停不下来！ [0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}$',
             'description': r're:.*m7show@163\.com.*',
-            'thumbnail': r're:^https?://.*\.jpg$',
+            'thumbnail': r're:^https?://.*\.png',
             'uploader': '7师傅',
             'is_live': True,
         },
@@ -37,7 +38,7 @@ class DouyuTVIE(InfoExtractor):
             'ext': 'flv',
             'title': 're:^小漠从零单排记！——CSOL2躲猫猫 [0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}$',
             'description': 'md5:746a2f7a253966a06755a912f0acc0d2',
-            'thumbnail': r're:^https?://.*\.jpg$',
+            'thumbnail': r're:^https?://.*\.png',
             'uploader': 'douyu小漠',
             'is_live': True,
         },
@@ -53,13 +54,28 @@ class DouyuTVIE(InfoExtractor):
             'ext': 'flv',
             'title': 're:^清晨醒脑！根本停不下来！ [0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}$',
             'description': r're:.*m7show@163\.com.*',
-            'thumbnail': r're:^https?://.*\.jpg$',
+            'thumbnail': r're:^https?://.*\.png',
             'uploader': '7师傅',
             'is_live': True,
         },
         'params': {
             'skip_download': True,
         },
+    }, {
+        'url': 'https://www.douyu.com/topic/ydxc?rid=6560603',
+        'info_dict': {
+            'id': '6560603',
+            'display_id': '6560603',
+            'ext': 'flv',
+            'title': 're:^阿余：新年快乐恭喜发财！ [0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}$',
+            'description': 're:.*直播时间.*',
+            'thumbnail': r're:^https?://.*\.png',
+            'uploader': '阿涛皎月Carry',
+            'live_status': 'is_live',
+        },
+        'params': {
+            'skip_download': True,
+        },
     }, {
         'url': 'http://www.douyu.com/xiaocang',
         'only_matching': True,
@@ -79,28 +95,24 @@ class DouyuTVIE(InfoExtractor):
             room_id = self._html_search_regex(
                 r'"room_id\\?"\s*:\s*(\d+),', page, 'room id')
 
-        # Grab metadata from mobile API
+        # Grab metadata from API
+        params = {
+            'aid': 'wp',
+            'client_sys': 'wp',
+            'time': int(time.time()),
+        }
+        params['auth'] = hashlib.md5(
+            f'room/{video_id}?{urllib.parse.urlencode(params)}zNzMV1y4EMxOHS6I5WKm'.encode()).hexdigest()
         room = self._download_json(
-            'http://m.douyu.com/html5/live?roomId=%s' % room_id, video_id,
-            note='Downloading room info')['data']
+            f'http://www.douyutv.com/api/v1/room/{room_id}', video_id,
+            note='Downloading room info', query=params)['data']
 
         # 1 = live, 2 = offline
         if room.get('show_status') == '2':
             raise ExtractorError('Live stream is offline', expected=True)
 
-        # Grab the URL from PC client API
-        # The m3u8 url from mobile API requires re-authentication every 5 minutes
-        tt = int(time.time())
-        signContent = 'lapi/live/thirdPart/getPlay/%s?aid=pcclient&rate=0&time=%d9TUk5fjjUjg9qIMH3sdnh' % (room_id, tt)
-        sign = hashlib.md5(signContent.encode('ascii')).hexdigest()
-        video_url = self._download_json(
-            'http://coapi.douyucdn.cn/lapi/live/thirdPart/getPlay/' + room_id,
-            video_id, note='Downloading video URL info',
-            query={'rate': 0}, headers={
-                'auth': sign,
-                'time': str(tt),
-                'aid': 'pcclient'
-            })['data']['live_url']
+        video_url = urljoin('https://hls3-akm.douyucdn.cn/', self._search_regex(r'(live/.*)', room['hls_url'], 'URL'))
+        formats, subs = self._extract_m3u8_formats_and_subtitles(video_url, room_id)
 
         title = unescapeHTML(room['room_name'])
         description = room.get('show_details')
@@ -110,12 +122,13 @@ class DouyuTVIE(InfoExtractor):
         return {
             'id': room_id,
             'display_id': video_id,
-            'url': video_url,
             'title': title,
             'description': description,
             'thumbnail': thumbnail,
             'uploader': uploader,
             'is_live': True,
+            'subtitles': subs,
+            'formats': formats,
         }
 
 
