@@ -1,6 +1,3 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 import uuid
 
 from .common import InfoExtractor
@@ -116,7 +113,6 @@ class LEGOIE(InfoExtractor):
                         'width': quality[2],
                     }),
                 formats.append(f)
-        self._sort_formats(formats)
 
         subtitles = {}
         sub_file_id = video.get('SubFileId')
