@@ -1,17 +1,11 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 import itertools
 import json
-import time
-import urllib
+import urllib.error
 
-from ..utils import (
-    ExtractorError,
-    parse_iso8601,
-    try_get,
-)
 from .common import InfoExtractor
+from ..utils import ExtractorError, parse_iso8601
+
+_BASE_URL_RE = r'https?://(?:www\.)?(?:watchnebula\.com|nebula\.app|nebula\.tv)'
 
 
 class NebulaBaseIE(InfoExtractor):
@@ -19,12 +13,10 @@ class NebulaBaseIE(InfoExtractor):
 
     _nebula_api_token = None
     _nebula_bearer_token = None
-    _zype_access_token = None
 
-    def _perform_nebula_auth(self):
-        username, password = self._get_login_info()
-        if not (username and password):
-            self.raise_login_required()
+    def _perform_nebula_auth(self, username, password):
+        if not username or not password:
+            self.raise_login_required(method='password')
 
         data = json.dumps({'email': username, 'password': password}).encode('utf8')
         response = self._download_json(
@@ -38,38 +30,10 @@ class NebulaBaseIE(InfoExtractor):
             note='Logging in to Nebula with supplied credentials',
             errnote='Authentication failed or rejected')
         if not response or not response.get('key'):
-            self.raise_login_required()
-
-        # save nebula token as cookie
-        self._set_cookie(
-            'nebula.app', 'nebula-auth',
-            urllib.parse.quote(
-                json.dumps({
-                    "apiToken": response["key"],
-                    "isLoggingIn": False,
-                    "isLoggingOut": False,
-                }, separators=(",", ":"))),
-            expire_time=int(time.time()) + 86400 * 365,
-        )
+            self.raise_login_required(method='password')
 
         return response['key']
 
-    def _retrieve_nebula_api_token(self):
-        """
-        Check cookie jar for valid token. Try to authenticate using credentials if no valid token
-        can be found in the cookie jar.
-        """
-        nebula_cookies = self._get_cookies('https://nebula.app')
-        nebula_cookie = nebula_cookies.get('nebula-auth')
-        if nebula_cookie:
-            self.to_screen('Authenticating to Nebula with token from cookie jar')
-            nebula_cookie_value = urllib.parse.unquote(nebula_cookie.value)
-            nebula_api_token = self._parse_json(nebula_cookie_value, None).get('apiToken')
-            if nebula_api_token:
-                return nebula_api_token
-
-        return self._perform_nebula_auth()
-
     def _call_nebula_api(self, url, video_id=None, method='GET', auth_type='api', note=''):
         assert method in ('GET', 'POST',)
         assert auth_type in ('api', 'bearer',)
@@ -100,35 +64,24 @@ class NebulaBaseIE(InfoExtractor):
                                          note='Authorizing to Nebula')
         return response['token']
 
-    def _fetch_zype_access_token(self):
-        """
-        Get a Zype access token, which is required to access video streams -- in our case: to
-        generate video URLs.
-        """
-        user_object = self._call_nebula_api('https://api.watchnebula.com/api/v1/auth/user/', note='Retrieving Zype access token')
-
-        access_token = try_get(user_object, lambda x: x['zype_auth_info']['access_token'], str)
-        if not access_token:
-            if try_get(user_object, lambda x: x['is_subscribed'], bool):
-                # TODO: Reimplement the same Zype token polling the Nebula frontend implements
-                # see https://github.com/ytdl-org/youtube-dl/pull/24805#issuecomment-749231532
-                raise ExtractorError(
-                    'Unable to extract Zype access token from Nebula API authentication endpoint. '
-                    'Open an arbitrary video in a browser with this account to generate a token',
-                    expected=True)
-            raise ExtractorError('Unable to extract Zype access token from Nebula API authentication endpoint')
-        return access_token
+    def _fetch_video_formats(self, slug):
+        stream_info = self._call_nebula_api(f'https://content.watchnebula.com/video/{slug}/stream/',
+                                            video_id=slug,
+                                            auth_type='bearer',
+                                            note='Fetching video stream info')
+        manifest_url = stream_info['manifest']
+        return self._extract_m3u8_formats_and_subtitles(manifest_url, slug)
 
     def _build_video_info(self, episode):
-        zype_id = episode['zype_id']
-        zype_video_url = f'https://player.zype.com/embed/{zype_id}.html?access_token={self._zype_access_token}'
+        fmts, subs = self._fetch_video_formats(episode['slug'])
         channel_slug = episode['channel_slug']
+        channel_title = episode['channel_title']
         return {
             'id': episode['zype_id'],
             'display_id': episode['slug'],
-            '_type': 'url_transparent',
-            'ie_key': 'Zype',
-            'url': zype_video_url,
+            'formats': fmts,
+            'subtitles': subs,
+            'webpage_url': f'https://nebula.tv/{episode["slug"]}',
             'title': episode['title'],
             'description': episode['description'],
             'timestamp': parse_iso8601(episode['published_at']),
@@ -138,29 +91,27 @@ class NebulaBaseIE(InfoExtractor):
                 'height': key,
             } for key, tn in episode['assets']['thumbnail'].items()],
             'duration': episode['duration'],
-            'channel': episode['channel_title'],
+            'channel': channel_title,
             'channel_id': channel_slug,
-            'channel_url': f'https://nebula.app/{channel_slug}',
-            'uploader': episode['channel_title'],
+            'channel_url': f'https://nebula.tv/{channel_slug}',
+            'uploader': channel_title,
             'uploader_id': channel_slug,
-            'uploader_url': f'https://nebula.app/{channel_slug}',
-            'series': episode['channel_title'],
-            'creator': episode['channel_title'],
+            'uploader_url': f'https://nebula.tv/{channel_slug}',
+            'series': channel_title,
+            'creator': channel_title,
         }
 
     def _perform_login(self, username=None, password=None):
-        # FIXME: username should be passed from here to inner functions
-        self._nebula_api_token = self._retrieve_nebula_api_token()
+        self._nebula_api_token = self._perform_nebula_auth(username, password)
         self._nebula_bearer_token = self._fetch_nebula_bearer_token()
-        self._zype_access_token = self._fetch_zype_access_token()
 
 
 class NebulaIE(NebulaBaseIE):
-    _VALID_URL = r'https?://(?:www\.)?(?:watchnebula\.com|nebula\.app)/videos/(?P<id>[-\w]+)'
+    _VALID_URL = rf'{_BASE_URL_RE}/videos/(?P<id>[-\w]+)'
     _TESTS = [
         {
-            'url': 'https://nebula.app/videos/that-time-disney-remade-beauty-and-the-beast',
-            'md5': 'fe79c4df8b3aa2fea98a93d027465c7e',
+            'url': 'https://nebula.tv/videos/that-time-disney-remade-beauty-and-the-beast',
+            'md5': '14944cfee8c7beeea106320c47560efc',
             'info_dict': {
                 'id': '5c271b40b13fd613090034fd',
                 'ext': 'mp4',
@@ -172,14 +123,19 @@ class NebulaIE(NebulaBaseIE):
                 'channel_id': 'lindsayellis',
                 'uploader': 'Lindsay Ellis',
                 'uploader_id': 'lindsayellis',
-            },
-            'params': {
-                'usenetrc': True,
+                'timestamp': 1533009600,
+                'uploader_url': 'https://nebula.tv/lindsayellis',
+                'series': 'Lindsay Ellis',
+                'display_id': 'that-time-disney-remade-beauty-and-the-beast',
+                'channel_url': 'https://nebula.tv/lindsayellis',
+                'creator': 'Lindsay Ellis',
+                'duration': 2212,
+                'thumbnail': r're:https://\w+\.cloudfront\.net/[\w-]+\.jpeg?.*',
             },
         },
         {
-            'url': 'https://nebula.app/videos/the-logistics-of-d-day-landing-craft-how-the-allies-got-ashore',
-            'md5': '6d4edd14ce65720fa63aba5c583fb328',
+            'url': 'https://nebula.tv/videos/the-logistics-of-d-day-landing-craft-how-the-allies-got-ashore',
+            'md5': 'd05739cf6c38c09322422f696b569c23',
             'info_dict': {
                 'id': '5e7e78171aaf320001fbd6be',
                 'ext': 'mp4',
@@ -191,14 +147,18 @@ class NebulaIE(NebulaBaseIE):
                 'channel_id': 'realengineering',
                 'uploader': 'Real Engineering',
                 'uploader_id': 'realengineering',
-            },
-            'params': {
-                'usenetrc': True,
+                'series': 'Real Engineering',
+                'display_id': 'the-logistics-of-d-day-landing-craft-how-the-allies-got-ashore',
+                'creator': 'Real Engineering',
+                'duration': 841,
+                'channel_url': 'https://nebula.tv/realengineering',
+                'uploader_url': 'https://nebula.tv/realengineering',
+                'thumbnail': r're:https://\w+\.cloudfront\.net/[\w-]+\.jpeg?.*',
             },
         },
         {
-            'url': 'https://nebula.app/videos/money-episode-1-the-draw',
-            'md5': '8c7d272910eea320f6f8e6d3084eecf5',
+            'url': 'https://nebula.tv/videos/money-episode-1-the-draw',
+            'md5': 'ebe28a7ad822b9ee172387d860487868',
             'info_dict': {
                 'id': '5e779ebdd157bc0001d1c75a',
                 'ext': 'mp4',
@@ -210,9 +170,13 @@ class NebulaIE(NebulaBaseIE):
                 'channel_id': 'tom-scott-presents-money',
                 'uploader': 'Tom Scott Presents: Money',
                 'uploader_id': 'tom-scott-presents-money',
-            },
-            'params': {
-                'usenetrc': True,
+                'uploader_url': 'https://nebula.tv/tom-scott-presents-money',
+                'duration': 825,
+                'channel_url': 'https://nebula.tv/tom-scott-presents-money',
+                'series': 'Tom Scott Presents: Money',
+                'display_id': 'money-episode-1-the-draw',
+                'thumbnail': r're:https://\w+\.cloudfront\.net/[\w-]+\.jpeg?.*',
+                'creator': 'Tom Scott Presents: Money',
             },
         },
         {
@@ -233,32 +197,54 @@ class NebulaIE(NebulaBaseIE):
         return self._build_video_info(video)
 
 
-class NebulaCollectionIE(NebulaBaseIE):
-    IE_NAME = 'nebula:collection'
-    _VALID_URL = r'https?://(?:www\.)?(?:watchnebula\.com|nebula\.app)/(?!videos/)(?P<id>[-\w]+)'
+class NebulaSubscriptionsIE(NebulaBaseIE):
+    IE_NAME = 'nebula:subscriptions'
+    _VALID_URL = rf'{_BASE_URL_RE}/myshows'
     _TESTS = [
         {
-            'url': 'https://nebula.app/tom-scott-presents-money',
+            'url': 'https://nebula.tv/myshows',
+            'playlist_mincount': 1,
+            'info_dict': {
+                'id': 'myshows',
+            },
+        },
+    ]
+
+    def _generate_playlist_entries(self):
+        next_url = 'https://content.watchnebula.com/library/video/?page_size=100'
+        page_num = 1
+        while next_url:
+            channel = self._call_nebula_api(next_url, 'myshows', auth_type='bearer',
+                                            note=f'Retrieving subscriptions page {page_num}')
+            for episode in channel['results']:
+                yield self._build_video_info(episode)
+            next_url = channel['next']
+            page_num += 1
+
+    def _real_extract(self, url):
+        return self.playlist_result(self._generate_playlist_entries(), 'myshows')
+
+
+class NebulaChannelIE(NebulaBaseIE):
+    IE_NAME = 'nebula:channel'
+    _VALID_URL = rf'{_BASE_URL_RE}/(?!myshows|videos/)(?P<id>[-\w]+)'
+    _TESTS = [
+        {
+            'url': 'https://nebula.tv/tom-scott-presents-money',
             'info_dict': {
                 'id': 'tom-scott-presents-money',
                 'title': 'Tom Scott Presents: Money',
                 'description': 'Tom Scott hosts a series all about trust, negotiation and money.',
             },
             'playlist_count': 5,
-            'params': {
-                'usenetrc': True,
-            },
         }, {
-            'url': 'https://nebula.app/lindsayellis',
+            'url': 'https://nebula.tv/lindsayellis',
             'info_dict': {
                 'id': 'lindsayellis',
                 'title': 'Lindsay Ellis',
                 'description': 'Enjoy these hottest of takes on Disney, Transformers, and Musicals.',
             },
-            'playlist_mincount': 100,
-            'params': {
-                'usenetrc': True,
-            },
+            'playlist_mincount': 2,
         },
     ]
 
